@@ -8,42 +8,43 @@ use std::path::Path;
 #[cfg(unix)]
 use which::which;
 
-use grib::context::{Grib2, GribError};
+use grib::context::Grib2;
+use grib::error::*;
 use grib::reader::SeekableGrib2Reader;
 
 pub enum CliError {
-    GribError(GribError),
-    ParseNumberError(ParseIntError),
-    IOError(Error, String),
+    Grib(GribError),
+    ParseNumber(ParseIntError),
+    IO(Error, String),
 }
 
 impl Display for CliError {
     fn fmt(&self, f: &mut Formatter) -> fmt::Result {
         match self {
-            Self::GribError(e) => write!(f, "{}", e),
-            Self::ParseNumberError(e) => write!(f, "{:#?}", e),
-            Self::IOError(e, path) => write!(f, "{}: {}", e, path),
+            Self::Grib(e) => write!(f, "{}", e),
+            Self::ParseNumber(e) => write!(f, "{:#?}", e),
+            Self::IO(e, path) => write!(f, "{}: {}", e, path),
         }
     }
 }
 
 impl From<GribError> for CliError {
     fn from(e: GribError) -> Self {
-        Self::GribError(e)
+        Self::Grib(e)
     }
 }
 
 impl From<ParseIntError> for CliError {
     fn from(e: ParseIntError) -> Self {
-        Self::ParseNumberError(e)
+        Self::ParseNumber(e)
     }
 }
 
 pub fn grib(file_name: &str) -> Result<Grib2<SeekableGrib2Reader<BufReader<File>>>, CliError> {
     let path = Path::new(file_name);
-    let f = File::open(&path).map_err(|e| CliError::IOError(e, path.display().to_string()))?;
+    let f = File::open(&path).map_err(|e| CliError::IO(e, path.display().to_string()))?;
     let f = BufReader::new(f);
-    Ok(Grib2::<SeekableGrib2Reader<BufReader<File>>>::read_with_seekable(f)?)
+    Ok(grib::from_reader(f)?)
 }
 
 #[cfg(unix)]
