@@ -1,20 +1,18 @@
 use chrono::{offset::TimeZone, Utc};
 use std::convert::TryInto;
-use std::fmt::{self, Display, Formatter};
 use std::io::{self, Read, Seek, SeekFrom};
 use std::result::Result;
 
 use crate::codetables::SUPPORTED_PROD_DEF_TEMPLATE_NUMBERS;
-use crate::context::{
-    BitMap, GridDefinition, Identification, Indicator, ProdDefinition, ReprDefinition, SectionBody,
-    SectionInfo,
-};
+use crate::context::{SectionBody, SectionInfo};
+use crate::datatypes::*;
+use crate::error::*;
 
-const SECT0_IS_MAGIC: &'static [u8] = b"GRIB";
+const SECT0_IS_MAGIC: &[u8] = b"GRIB";
 const SECT0_IS_MAGIC_SIZE: usize = SECT0_IS_MAGIC.len();
 const SECT0_IS_SIZE: usize = 16;
 const SECT_HEADER_SIZE: usize = 5;
-const SECT8_ES_MAGIC: &'static [u8] = b"7777";
+const SECT8_ES_MAGIC: &[u8] = b"7777";
 const SECT8_ES_SIZE: usize = SECT8_ES_MAGIC.len();
 
 macro_rules! read_as {
@@ -110,7 +108,7 @@ impl<R: Read + Seek> Grib2Read for SeekableGrib2Reader<R> {
         let fsize = read_as!(u64, buf, 8);
 
         Ok(Indicator {
-            discipline: discipline,
+            discipline,
             total_length: fsize,
         })
     }
@@ -167,7 +165,7 @@ impl<R: Read + Seek> Grib2Read for SeekableGrib2Reader<R> {
 
         let body_size = meta.size - SECT_HEADER_SIZE;
         let mut buf = vec![0; body_size];
-        self.read_exact(&mut buf.as_mut_slice())?;
+        self.read_exact(buf.as_mut_slice())?;
 
         Ok(buf.into_boxed_slice())
     }
@@ -235,7 +233,7 @@ pub fn unpack_sect4_body<R: Read>(f: &mut R, body_size: usize) -> Result<Section
 
     Ok(SectionBody::Section4(ProdDefinition {
         num_coordinates: read_as!(u16, buf, 0),
-        prod_tmpl_num: prod_tmpl_num,
+        prod_tmpl_num,
         templated: templated.into_boxed_slice(),
         template_supported: SUPPORTED_PROD_DEF_TEMPLATE_NUMBERS.contains(&prod_tmpl_num),
     }))
@@ -278,35 +276,6 @@ fn skip_sect7_body<R: Seek>(f: &mut R, body_size: usize) -> Result<SectionBody,
     Ok(SectionBody::Section7)
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash)]
-pub enum ParseError {
-    ReadError(String),
-    FileTypeCheckError(String),
-    NotGRIB,
-    GRIBVersionMismatch(u8),
-    UnknownSectionNumber(u8),
-    EndSectionMismatch,
-}
-
-impl Display for ParseError {
-    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-        match self {
-            Self::ReadError(s) => write!(f, "Read error: {}", s),
-            Self::FileTypeCheckError(s) => write!(f, "Error in checking file type: {}", s),
-            Self::NotGRIB => write!(f, "Not GRIB data"),
-            Self::GRIBVersionMismatch(i) => write!(f, "Not GRIB version 2: {}", i),
-            Self::UnknownSectionNumber(s) => write!(f, "Unknown section number: {}", s),
-            Self::EndSectionMismatch => write!(f, "Content of End Section is not valid"),
-        }
-    }
-}
-
-impl From<io::Error> for ParseError {
-    fn from(e: io::Error) -> Self {
-        Self::ReadError(e.to_string())
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
